summaryrefslogtreecommitdiff
path: root/src/mem/snoop_filter.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/mem/snoop_filter.hh')
-rwxr-xr-xsrc/mem/snoop_filter.hh4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mem/snoop_filter.hh b/src/mem/snoop_filter.hh
index 2a8d1ce21..3851e5810 100755
--- a/src/mem/snoop_filter.hh
+++ b/src/mem/snoop_filter.hh
@@ -141,9 +141,9 @@ class SnoopFilter : public SimObject {
* reqLookupResult.
*
* @param will_retry This request will retry on this bus / snoop filter
* @param cpkt Request packet, merely for sanity checking
*/
- void finishRequest(bool will_retry, const Packet* cpkt);
+ void finishRequest(bool will_retry, const Addr addr);
/**
* Handle an incoming snoop from below (the master port). These
@@ -141,9 +141,9 @@ class SnoopFilter : public SimObject {
*
* @param will_retry This request will retry on this bus / snoop filter
- * @param cpkt Request packet, merely for sanity checking
+ * @param addr Packet address, merely for sanity checking
*/